/**
 * PETALS - PETALS Services Platform. Copyright (c) 2007 EBM Websourcing,
 * http://www.ebmwebsourcing.com/
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version. This library is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 * 
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */
package org.ow2.petals.se.eip.patterns;

import org.ow2.petals.component.framework.api.message.Exchange;
import org.ow2.petals.se.eip.ExchangeContext;
import org.ow2.petals.se.eip.async.CommonAsyncContext;

/**
 * The pattern interface
 * 
 * @author alouis
 * @author chamerling - eBM WebSourcing
 * @author Frederic Gardes
 */
public interface Pattern {
    /**
     * Initialize the pattern
     * 
     */
    void init();

    /**
     * Process the Pattern.
     * 
     * @param exchange
     *            The exchange to process
     * @param context
     *            The context of the exchange
     */
    boolean processPattern(Exchange exchange, ExchangeContext context);

    /**
     * Process an exchange for an asynchronous pattern.
     * 
     * @param exchange
     *            The exchange to process
     * @param context
     *            The context of the exchange
     * @param asyncContext
     *            The EIP asynchronous context
     * @param expired
     *            true if the asynchronous exchange is expired, false else
     */
    boolean processAsyncPattern(Exchange exchange, ExchangeContext context,
            CommonAsyncContext asyncContext, boolean expired);

    /**
     * Get the pattern name.
     * 
     * @return The name
     */
    String getName();
}
