/**
 * PETALS - PETALS Services Platform. Copyright (c) 2005 EBM Websourcing,
 * http://www.ebmwebsourcing.com/
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version. This library is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 * 
 * ---------------------------------------------------------------------------
 * ---------------------------------------------------------------------------
 */
package org.ow2.petals.se.eip.patterns;

import java.util.List;
import java.util.SortedMap;
import java.util.TreeMap;
import java.util.concurrent.CopyOnWriteArrayList;

import javax.xml.xpath.XPathExpressionException;

import org.ow2.petals.component.framework.api.configuration.ConfigurationExtensions;
import org.ow2.petals.se.eip.EIPConstants;
import org.ow2.petals.se.eip.ExchangeContext;
import org.w3c.dom.Document;

/**
 * Helper to route<br />
 * TODO use the XSLTUtil instead of create a XPath engine on each call
 * 
 * @author Frederic Gardes
 */
public class RouterEngine {

	/**
	 * @param extensions
	 * @return
	 */
	public List<String> retrieveConditions(final ConfigurationExtensions extensions) {
		final List<String> conditions = new CopyOnWriteArrayList<String>();
		final SortedMap<Integer, String> orderedConditions = new TreeMap<Integer, String>();
		for (final String param : extensions.keySet()) {
			if (EIPConstants.TEST.equals(param)) {
				conditions.add(extensions.get(param));
				break;
			} else if (param.startsWith(EIPConstants.TEST)) {
				final String indexString = param.substring(EIPConstants.TEST.length());
				orderedConditions.put(Integer.valueOf(indexString), extensions.get(param));
			}
		}
		if (conditions.size() == 0) {
			conditions.addAll(orderedConditions.values());
		}
		return conditions;
	}

	/**
	 * @param conditions
	 * @param inMessage
	 * @param context
	 * @return
	 * @throws XPathExpressionException
	 */
	public int retrieveTargetedConsumesListIdentifier(final List<String> conditions, final Document inMessage, final ExchangeContext context) throws XPathExpressionException {
		int targetedConsumesListIndentifier = conditions.size();
		for (int i = 0; i < conditions.size(); i++) {
			if (conditions.get(i) != null && inMessage.getDocumentElement() != null && PatternHelper.evaluateXPathCondition(conditions.get(i), inMessage.getDocumentElement())) {
				targetedConsumesListIndentifier = i;
				break;
			}
		}
		return targetedConsumesListIndentifier;
	}

}
